#   -------------------------------------------------------------
#   Copyright (c) Microsoft Corporation. All rights reserved.
#   -------------------------------------------------------------
"""Utilities for Reading and Writing for Churn Prediction on Spark"""
from typing import List, Tuple, Union

from pyspark.sql import SparkSession
from pyspark.sql.dataframe import DataFrame


def _read_parquet_from_adls(
    storage_name: str, container_name: str, dir_name: str, file_name: Union[str, List[str], Tuple[str]],
) -> DataFrame:
    """
    Read Parquet from Azure Data Lake v2

    :param storage_name:
    :param container_name:
    :param dir_name:
    :param file_name:
    :return:
    """
    base_path = f"abfss://{container_name}@{storage_name}.dfs.core.windows.net/{dir_name}"

    paths = f"{base_path}/{file_name}" if isinstance(file_name, str) else [f"{base_path}/{name}" for name in file_name]

    return SparkSession.builder.getOrCreate().read.option("basePath", base_path).load(paths, format="parquet")
