# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT license.
# ---------------------------------------------------------

import io
import os
from os import environ

from setuptools import find_packages
from distutils.core import setup

VERSION = io.open("./VERSION", encoding="utf-8").read()

CLASSIFIERS = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "Intended Audience :: System Administrators",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
]

DEPENDENCIES = [
    "azure-identity",
    "azure-mgmt-compute",
    "azure-mgmt-storage",
    "azure-storage-file-datalake",
    "numpy",
    "pandas>=1.0.0",
    "pyspark>=3.0",
    "synapseml",
]


def read(file_path, encoding="utf-8"):
    return io.open(file_path, encoding=encoding).read()


core_requires = read("./requirements.txt")
test_requires = read("./requirements.test.txt")
README = read("./README.md")
VERSION = read("./VERSION")

EXTRAS = {
    "required": core_requires,
    "test": test_requires,
    "all": core_requires + test_requires,
}

setup(
    name="azure-gamedev-spark",
    version=VERSION,
    long_description=README,
    description="Azure GameDev Spark",
    long_description_content_type="text/x-rst",
    author="Microsoft Corp",
    license="Copyright Microsoft",
    url="https://azure.microsoft.com/en-us/overview/ai-platform/",
    classifiers=CLASSIFIERS,
    namespace_packages=[],
    packages=find_packages(exclude=["*.tests"]),
    setup_requires=["setuptools_scm"],
    include_package_data=True,
    install_requires=DEPENDENCIES,
    extras_require=EXTRAS,
    package_dir={"azure-gamedev-spark": "azure-gamedev-spark"},
    python_requires=">=3.7,<4",
)
